global datefirst = "15dec2020"
global datelast = "15may2021"  
global initialcontrol = "15dec2020"
global finalcontrol = "14feb2021"
global treatment = "15feb2021"

ssc install labutil

use  IFDP_note_for_chartone_final, clear

collapse vax*, by(country2)

egen vaxtot = rowtotal(vax*)
gen round_vaxtot = round(-vaxtot)


labmask round_vaxtot, values(country2)

graph hbar  vax_init vax_med vax_fin, ///
over(round_vaxtot, label(nolabels)) ///
stack  legend( rows(1) label(1 "Feb. 15") label(2 "Apr. 15") label(3 "May 15") )  ///
asyvars ///
bar(1, color(blue) fintensity(inten80)) ///
bar(2, color(gray) fintensity(inten60)) ///
bar(3, color(orange) fintensity(inten100)) ///
ysc(r(0 125)) ///  ysc(r(0 125))
ylab(0 40 80 120, nogrid) ///
ylabel(, labsize(medium) ) ///
graphregion(fcolor(white)) ///
subtitle(" ") ///
b1title("Vaccine Doses Administered per 100 People") ///
ytitle("") nofill name(FIGURE1, replace) 






use IFDP_note_for_charttwo_final, clear


sum date if tin($initialcontrol,$initialcontrol)
global t1 = r(mean)
sum date if tin($finalcontrol,$finalcontrol)
global t2 = r(mean)

xtline vax if tin($datefirst,$datelast), ///
ylabel(, labsize(small) angle(horizontal)) ///
ttick(1dec2020 1jan2021 1feb2021 1mar2021 1apr2021 1may2021 ) ///
tlabel(15dec2020 "Dec.20" 15jan2021 "Jan.21" 15feb2021 "Feb.21" 15mar2021 "Mar.21" 15apr2021 "Apr.21" 12may2021 "May 21"  , notick format(%tdm) labsize(small)) ///
title("Vaccines Administered") ///
ytitle("Doses per 100 People", size(medsmall)) ///
xtitle(, size(medium)) ///
xlabel(,  labsize(medium)) ///
ylabel(,  tposition(inside)) ///
overlay xtitle("") ///
plot1(lwidth(medthick) lcolor(red)) ///
plot2(lwidth(thick) lcolor(blue)) ///
tline($t1 $t2, lcol(black) lpattern(shortdash)) ///
legend(order(2 "Fast Vaccinators" 1 "Slow Vaccinators") region(lstyle(none)) nobox size(small) cols(1) position(0) bplacement(nwest)) ///
graphregion(fcolor(white)) name(vaxx, replace) nodraw



xtline deathsvar if tin($datefirst,$datelast), ///
overlay xtitle("") legend(off) graphregion(fcolor(white)) ///
ylabel(, labsize(small)  format(%9.0f) angle(horizontal)) ///
ttick(1dec2020 1jan2021 1feb2021 1mar2021 1apr2021 1may2021 ) ///
tlabel(15dec2020 "Dec.20" 15jan2021 "Jan.21" 15feb2021 "Feb.21" 15mar2021 "Mar.21" 15apr2021 "Apr.21" 12may2021 "May 21"  , notick format(%tdm) labsize(small)) ///
title("COVID-19 Deaths") ///
ytitle("Deaths per Million", size(medsmall)) ///
xtitle(, size(medium)) ///
plot1(lwidth(medthick) lcolor(red)) ///
plot2(lwidth(thick) lcolor(blue)) ///
tline($t1 $t2, lcol(black) lpatter(shortdash)) ///
xlabel(,  labsize(medium)) ///
ylabel(,  tposition(inside)) ///
name(deathsv, replace) nodraw



xtline stringencyvar if tin($datefirst,$datelast), ///
ylabel(, labsize(small) angle(horizontal)) ///
ysc(r(55 80)) ///
ylabel(55(5)80) ///
ttick(1dec2020 1jan2021 1feb2021 1mar2021 1apr2021 1may2021 ) ///
tlabel(15dec2020 "Dec.20" 15jan2021 "Jan.21" 15feb2021 "Feb.21" 15mar2021 "Mar.21" 15apr2021 "Apr.21" 12may2021 "May 21"  , notick format(%tdm) labsize(small)) ///
title("Oxford Stringency Index") ///
ytitle("Index (0-100, 100=Strictest)", size(medsmall)) ///
xtitle(, size(medium)) ///
plot1(lwidth(medthick) lcolor(red)) ///
plot2(lwidth(thick) lcolor(blue)) ///
tline($t1 $t2, lcol(black) lpatter(shortdash)) ///
xlabel(,  labsize(medium)) ///
ylabel(,  tposition(inside)) ///
overlay xtitle("") legend(off) graphregion(fcolor(white)) name(stringencyv, replace) nodraw




xtline mobvar if tin($datefirst,$datelast), ///
ylabel(, labsize(small) angle(horizontal)) ///
ttick(1dec2020 1jan2021 1feb2021 1mar2021 1apr2021 1may2021 ) ///
tlabel(15dec2020 "Dec.20" 15jan2021 "Jan.21" 15feb2021 "Feb.21" 15mar2021 "Mar.21" 15apr2021 "Apr.21" 12may2021 "May 21"  , notick format(%tdm) labsize(small)) ///
title("Google Mobility") ///
ytitle("Index (Jan.3-Feb.6 2020=100)", size(medsmall)) ///
xtitle(, size(medium)) ///
plot1(lwidth(medthick) lcolor(red)) ///
plot2(lwidth(thick) lcolor(blue)) ///
tline($t1 $t2, lcol(black) lpatter(shortdash)) ///
xlabel(,  labsize(medium)) ///
ylabel(,  tposition(inside)) ///
overlay xtitle("") legend(off) graphregion(fcolor(white)) name(mobvarv, replace) nodraw




graph combine vaxx deathsv stringencyv   mobvarv ,  rows(2) graphregion(fcolor(white))  ///
subtitle(" ") ///
name(FIGURE2, replace)





global datefirst = "15dec2020"
global datelast = "15may2021"  
global initialcontrol = "15dec2020"
global finalcontrol = "14feb2021"
global treatment = "15feb2021"

sort leader
by leader: sum mobvar stringencyvar deathsvar vax if tin($initialcontrol,$finalcontrol)
by leader: sum mobvar stringencyvar deathsvar vax if tin($treatment,$datelast)













use IFDP_note_for_chartthree_final, clear

sum date if tin($initialcontrol,$initialcontrol)
global t1 = r(mean)
sum date if tin($finalcontrol,$finalcontrol)
global t2 = r(mean)



graph twoway ///
(tsline gapd gapd16 gapd84 gapd5 gapd95 if leader==0 & tin($datefirst,$datelast), ///
lcolor(navy olive olive red red black) ///
lwidth(.7 .45 .45 .3 .3 .2) ///
yline(0, lcolor(black) lwidth(.1)) ///
legend(off) ///
lpattern(solid dash dash dash dash solid) ///
ttext(7 19mar2021 "95th percentile", justification(left) color(red) size(4.0)) ///
ttext(-7 22apr2021 "5th percentile", justification(left) color(red) size(4.0)) ///
ttext(2 31mar2021 "84th percentile", justification(left) color(olive) size(4.0)) ///
ttext(-2.0 8apr2021 "16th percentile", justification(left) color(olive) size(4.0)) ///
ttext(-5.1 1mar2021 "Actual", justification(left) color(navy) size(4.6)) ///
xtitle("") graphregion(fcolor(white)) ///
ylabel(, labsize(medsmall)  format(%9.0f) angle(horizontal)) ///
ttick(1dec2020 1jan2021 1feb2021 1mar2021 1apr2021 1may2021 ) ///
tlabel(15dec2020 "Dec.20" 15jan2021 "Jan.21" 15feb2021 "Feb.21" 15mar2021 "Mar.21" 15apr2021 "Apr.21" 10may2021 "May 21"  , notick format(%tdm) labsize(medsmall)) ///
title("Differential COVID-19 Deaths") ///
ytitle("Deaths per Million", size(medsmall)) ///
xtitle(, size(medium)) ///
tline($t1 $t2, lcol(black) lpatter(shortdash))  ///
xlabel(,  labsize(medium)) ///
ylabel(,  tposition(inside))), ///
name(FIGURE3, replace) 

