use temp_scm_repetitions, clear


set obs 1000
gen n = _n
gen gapvar_c = .
gen gapvar_m = .
gen gapvar_d = .

drop leader*

gen leader = 1 if newleader == 0
replace leader = 0 if newleader == 1





foreach i in 5 10 16 84 90 95 {

egen gapd`i' = rowpctile(gapdeathsvar*) if leader==0, p(`i')
egen gapc`i' = rowpctile(gapcasesvar*) if leader==0, p(`i')
egen gapm`i' = rowpctile(gapmobvar*) if leader==0, p(`i')
egen gapv`i' = rowpctile(gapvax*) if leader==0, p(`i')


}


drop casesvar*
drop deathsvar*
drop vax*
drop stringencyvar*
drop mobvar*
drop mcasesvar*
drop mdeathsvar*
drop mvax*
drop mstringencyvar*

drop gapcasesvar*
drop gapdeathsvar*
drop gapstringencyvar*
drop gapmobvar*
drop gapvax*
drop mmobvar*

drop if leader==.

merge 1:1 leader date using "IFDP_note_for_charttwo_final", nogenerate







egen casesvar00 = mean(casesvar) if leader==0, by(date)
egen casesvar0 = mean(casesvar00), by(date)
egen casesvar11 = mean(casesvar) if leader==1, by(date)
egen casesvar1 = mean(casesvar11), by(date)
gen gapc = casesvar1 - casesvar0


egen deathsvar00 = mean(deathsvar) if leader==0, by(date)
egen deathsvar0 = mean(deathsvar00), by(date)
egen deathsvar11 = mean(deathsvar) if leader==1, by(date)
egen deathsvar1 = mean(deathsvar11), by(date)
gen gapd = deathsvar1 - deathsvar0



egen mobvar00 = mean(mobvar) if leader==0, by(date)
egen mobvar0 = mean(mobvar00), by(date)
egen mobvar11 = mean(mobvar) if leader==1, by(date)
egen mobvar1 = mean(mobvar11), by(date)
gen gapm = mobvar1 - mobvar0




egen vaxvar00 = mean(vax) if leader==0, by(date)
egen vaxvar0 = mean(vaxvar00), by(date)
egen vaxvar11 = mean(vax) if leader==1, by(date)
egen vaxvar1 = mean(vaxvar11), by(date)
gen gapv = vaxvar1 - vaxvar0























preserve
keep if tin($datefirst,$datelast)
keep if leader==0
keep date gapd gapd16 gapd84 gapd5 gapd95  leader
save IFDP_note_for_chartthree_final, replace
restore




graph twoway ///
(tsline gapd gapd16 gapd84 gapd5 gapd95 if leader==0 & tin($datefirst,$datelast), ///
lcolor(navy olive olive red red black) ///
lwidth(.7 .45 .45 .3 .3 .2) ///
yline(0, lcolor(black) lwidth(.1)) ///
legend(off) ///
lpattern(solid dash dash dash dash solid) ///
ttext(7 19mar2021 "95th percentile", justification(left) color(red) size(4.0)) ///
ttext(-7 22apr2021 "5th percentile", justification(left) color(red) size(4.0)) ///
ttext(2 31mar2021 "84th percentile", justification(left) color(olive) size(4.0)) ///
ttext(-2.0 8apr2021 "16th percentile", justification(left) color(olive) size(4.0)) ///
ttext(-5.1 1mar2021 "Actual", justification(left) color(navy) size(4.6)) ///
xtitle("") graphregion(fcolor(white)) ///
ylabel(, labsize(medsmall)  format(%9.0f) angle(horizontal)) ///
ttick(1dec2020 1jan2021 1feb2021 1mar2021 1apr2021 1may2021 ) ///
tlabel(15dec2020 "Dec.20" 15jan2021 "Jan.21" 15feb2021 "Feb.21" 15mar2021 "Mar.21" 15apr2021 "Apr.21" 10may2021 "May 21"  , notick format(%tdm) labsize(medsmall)) ///
title("Differential COVID-19 Deaths") ///
ytitle("Deaths per Million", size(medsmall)) ///
xtitle(, size(medium)) ///
tline($t1 $t2, lcol(black) lpatter(shortdash))  ///
xlabel(,  labsize(medium)) ///
ylabel(,  tposition(inside))), ///
name(FIGURE3, replace) 






graph twoway ///
(tsline gapm gapm16 gapm84 gapm5 gapm95 if leader==0 & tin($datefirst,$datelast), ///
lcolor(navy olive olive red red ) ///
lwidth(.7 .45 .45 .3 .3 .2) ///
yline(0, lcolor(black) lwidth(.1)) ///
legend(off) ///
lpattern(solid dash dash dash dash solid) ///
///ttext(7 19mar2021 "95th percentile", justification(left) color(red) size(4.0)) ///
///ttext(-7 22apr2021 "5th percentile", justification(left) color(red) size(4.0)) ///
///ttext(2 31mar2021 "84th percentile", justification(left) color(olive) size(4.0)) ///
///ttext(-2.0 8apr2021 "16th percentile", justification(left) color(olive) size(4.0)) ///
///ttext(-5.1 1mar2021 "Actual", justification(left) color(navy) size(4.6)) ///
xtitle("") graphregion(fcolor(white)) ///
ylabel(, labsize(medsmall)  format(%9.0f) angle(horizontal)) ///
ttick(1dec2020 1jan2021 1feb2021 1mar2021 1apr2021 1may2021 ) ///
tlabel(15dec2020 "Dec.20" 15jan2021 "Jan.21" 15feb2021 "Feb.21" 15mar2021 "Mar.21" 15apr2021 "Apr.21" 10may2021 "May 21"  , notick format(%tdm) labsize(medsmall)) ///
title("Differential Mobility") ///
ytitle("Deaths per Million", size(medsmall)) ///
xtitle(, size(medium)) ///
tline($t1 $t2, lcol(black) lpatter(shortdash))  ///
xlabel(,  labsize(medium)) ///
ylabel(,  tposition(inside))), ///
name(Figure3a, replace) 











graph twoway ///
(tsline gapc gapc16 gapc84 gapc5 gapc95 if leader==0 & tin($datefirst,$datelast), ///
lcolor(navy olive olive red red black) ///
lwidth(.7 .45 .45 .3 .3 .2) ///
yline(0, lcolor(black) lwidth(.1)) ///
legend(off) ///
lpattern(solid dash dash dash dash solid) ///
///ttext(7 19mar2021 "95th percentile", justification(left) color(red) size(4.0)) ///
///ttext(-7 22apr2021 "5th percentile", justification(left) color(red) size(4.0)) ///
///ttext(2 31mar2021 "84th percentile", justification(left) color(olive) size(4.0)) ///
///ttext(-2.0 8apr2021 "16th percentile", justification(left) color(olive) size(4.0)) ///
///ttext(-5.1 1mar2021 "Actual", justification(left) color(navy) size(4.6)) ///
xtitle("") graphregion(fcolor(white)) ///
ylabel(, labsize(medsmall)  format(%9.0f) angle(horizontal)) ///
ttick(1dec2020 1jan2021 1feb2021 1mar2021 1apr2021 1may2021 ) ///
tlabel(15dec2020 "Dec.20" 15jan2021 "Jan.21" 15feb2021 "Feb.21" 15mar2021 "Mar.21" 15apr2021 "Apr.21" 10may2021 "May 21"  , notick format(%tdm) labsize(medsmall)) ///
title("Differential Cases") ///
ytitle("Cases per Million", size(medsmall)) ///
xtitle(, size(medium)) ///
tline($t1 $t2, lcol(black) lpatter(shortdash))  ///
xlabel(,  labsize(medium)) ///
ylabel(,  tposition(inside))), ///
name(Figure3b, replace) 





