
use covid_countries_scm, clear


save temp_covid_countries_scm, replace

set scheme s1color, permanently 



global datefirst = "15dec2020"
global datelast = "15may2021"  
global initialcontrol = "15dec2020"
global finalcontrol = "14feb2021"
global treatment = "15feb2021"

sum date if tin($initialcontrol,$initialcontrol)
global t1 = r(mean)
global t1_5 = $t1+5
global t1_10 = $t1+10
global t1_15 = $t1+15
global t1_20 = $t1+20
global t1_25 = $t1+25
global t1_30 = $t1+30
global t1_35 = $t1+35
global t1_40 = $t1+40
global t1_45 = $t1+45
global t1_50 = $t1+50
global t1_55 = $t1+55
global t1_60 = $t1+60
global t1_65 = $t1+65
global t1_70 = $t1+70
global t1_75 = $t1+75

sum date if tin($finalcontrol,$finalcontrol)
global t2 = r(mean)
sum date if tin($treatment,$treatment)
global t3 = r(mean)

keep if tin($initialcontrol,$datelast)


///-----------------------------------
// DO SYNTHETIC CONTROL ON SYNTHETIC COUNTRY, 
///-----------------------------------

egen casesvar2 = mean(casesvar) if leader==1, by(date)
egen deathsvar2 = mean(deathsvar) if leader==1, by(date)
egen mobvar2 = mean(mobvar) if leader==1, by(date)
egen stringency2 = mean(stringencyvar) if leader==1, by(date)
egen vax2 = mean(vax) if leader==1, by(date)

replace casesvar = casesvar2 if country=="US"
replace deathsvar = deathsvar2 if country=="US"
replace mobvar = mobvar2 if country=="US"
replace stringencyvar = stringency2 if country=="US"
replace vax = vax2 if country=="US"

replace country="Vax Leaders" if country=="US"
drop if (leader==1 & country~="Vax Leaders")



encode country, gen(countryno) 
keep date country countryno ///
casesvar stringencyvar deathsvar vax mobvar ///
covidrelevant leader  
xtset countryno date


///--------------------------------
/// APPLY SYNTHETIC CONTROL
///--------------------------------

summarize countryno if country=="Vax Leaders"
global code = r(mean)

//synth2 casesvar stringencyvar($t1(2)$t2) casesvar($t1(2)$t2), ///
//trunit($code) trperiod($t3) fig keep(temp_results_scm, replace)

//synth2 casesvar casesvar($t1(2)$t2) , ///
//trunit($code) trperiod($t3) fig keep(temp_results_scm, replace)


	synth2 deathsvar ///
	deathsvar($t1(1)$t2) ///
	stringencyvar($t1(1)$t2) ///
	mobvar($t1(1)$t2) ///
	deathsvar($t1) ///
	deathsvar($t1_5) ///
	deathsvar($t1_10) ///
	deathsvar($t1_15) ///
	deathsvar($t1_20) ///
	deathsvar($t1_25) ///
	deathsvar($t1_30) ///
	deathsvar($t1_35) ///
	deathsvar($t1_40) ///
	deathsvar($t1_45) ///
	deathsvar($t1_50) ///
	deathsvar($t1_55) ///
	deathsvar($t2) ///
	stringencyvar($t1) ///
	stringencyvar($t1_5) ///
	stringencyvar($t1_10) ///
	stringencyvar($t1_15) ///
	stringencyvar($t1_20) ///
	stringencyvar($t1_25) ///
	stringencyvar($t1_30) ///
	stringencyvar($t1_35) ///
	stringencyvar($t1_40) ///
	stringencyvar($t1_45) ///
	stringencyvar($t1_50) ///
	stringencyvar($t1_55) ///
	stringencyvar($t2) ///
	mobvar($t1) ///
	mobvar($t1_5) ///
	mobvar($t1_10) ///
	mobvar($t1_15) ///
	mobvar($t1_20) ///
	mobvar($t1_25) ///
	mobvar($t1_30) ///
	mobvar($t1_35) ///
	mobvar($t1_40) ///
	mobvar($t1_45) ///
	mobvar($t1_50) ///
	mobvar($t1_55) ///
	mobvar($t2), ///
	trunit($code) trperiod($t3) ///
	keep(temp_results_scm, replace) 





save temp_postsynt, replace


use temp_results_scm, clear
decode _Co_Number, gen(country) 
save temp_results_scm, replace




///-----------------------------------
// DO CHART FOR SYNTHETIC CONTROL ON GROUPED COUNTRIES, PICK WEIGHTS FROM ABOVE
///-----------------------------------

use temp_covid_countries_scm, clear


sort country_coded date
merge m:m country using temp_results_scm, nogen 





sort vax
gen country2 = country
replace country2 = "Europe excluding UK" if leader==0 & europe==1
replace country2 = "Canada" if country=="Canada"
replace country2 = "United States" if country=="US"
replace country2 = "Others" if (country2~="Europe excluding UK" & country2~="Canada") & leader==0

sort date





cap drop vax_fin vax_med vax_init mean_vax_* aux_mean_vax_fin
ge vax_init = vax if tin(15Feb2021,15Feb2021)
ge vax_med  = vax if tin(15Apr2021,15Apr2021)
ge vax_fin  = vax if tin(15May2021,15May2021)

* auxiliary variables to trick stata
bys country2: egen mean_vax_init = mean(vax_init) 
bys country2: egen mean_vax_med  = mean(vax_med) 
bys country2: egen mean_vax_fin  = mean(vax_fin) 

replace vax_med = vax_med - mean_vax_init 
replace vax_fin = vax_fin - mean_vax_med 




//--------------------------
// SAVE DATA FOR FIGURE 1
//--------------------------
preserve 
keep vax_init vax_med vax_fin country country2
drop if vax_init==. & vax_med==. & vax_fin==.
save IFDP_note_for_chartone_final, replace
restore




gen synth_weight = round(1000*_W_Weight)
list country stringency _W_Weight if tin($datelast,$datelast)	




preserve
keep if tin($datelast,$datelast)	
rename _W_Weight country_weights
keep country stringency country_weights 
save temp_country_weights, replace
restore





replace synth_weight = 100 if leader==1



collapse casesvar deathsvar  vax stringencyvar mobvar [fw=synth_weight], by(leader date)
xtset leader date
label var leader "High vaccination Countries"
label var casesvar "New Cases Per Million"
label var deathsvar "New Deaths Per Million"
label var stringencyvar "Oxford Stringency Index"
label var mobvar "Google Mobility Index"
label var vax "Vaccines Given (% of pop.)"



list casesvar deathsvar vax leader if tin($datelast,$datelast)



format stringencyvar %5.0f




// Calculate difference in vaccination and mobility
tabulate leader if tin(31mar2021,31mar2021), sum(vax)
tabulate leader if tin(1jan2021,30mar2021), sum(vax)

tabulate leader if tin($initialcontrol,$finalcontrol), sum(mobvar)
tabulate leader if tin($treatment,$datelast), sum(mobvar)





//--------------------------
// SAVE DATA FOR FIGURE 2
//--------------------------
 preserve
keep if tin($datefirst,$datelast)
keep date leader stringencyvar vax deathsvar mobvar casesvar
save IFDP_note_for_charttwo_final, replace
restore




/*
/// TO CHECK THE WEIGHTS
use temp_country_weights, clear
sort country
browse country country_weights if country_weights>0 & country_weights~=.
*/


